==> okio-jvm-3.4.0-javadoc.jar: okio/okio/-e-o-f-exception/index.md <==
//[okio](../../../index.md)/[okio](../index.md)/[EOFException](index.md)

# EOFException

[common]\
expect open class [EOFException](index.md)(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)? = null) : [IOException](../-i-o-exception/index.md)

[nonJvm]\
actual open class [EOFException](index.md)(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?) : [IOException](../-i-o-exception/index.md)

[jvm]\
actual typealias [EOFException](index.md) = [EOFException](https://docs.oracle.com/javase/8/docs/api/java/io/EOFException.html)

## Constructors

| | |
|---|---|
| [EOFException](-e-o-f-exception.md) | [common]<br>expect constructor(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)? = null)<br>[nonJvm]<br>actual constructor(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?) |

## Properties

| Name | Summary |
|---|---|
| cause | [common, nonJvm]<br>[common]<br>open val [cause](../-file-not-found-exception/index.md#-654012527%2FProperties%2F1348982416): [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)?<br>[nonJvm]<br>open val [cause](../-file-not-found-exception/index.md#-654012527%2FProperties%2F1730460553): [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)? |
| message | [common, nonJvm]<br>[common]<br>open val [message](../-file-not-found-exception/index.md#1824300659%2FProperties%2F1348982416): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?<br>[nonJvm]<br>open val [message](../-file-not-found-exception/index.md#1824300659%2FProperties%2F1730460553): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)? |

==> okio-jvm-3.6.0-javadoc.jar: okio/okio/-e-o-f-exception/index.md <==
//[okio](../../../index.md)/[okio](../index.md)/[EOFException](index.md)

# EOFException

[common]\
expect open class [EOFException](index.md)(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)? = null) : [IOException](../-i-o-exception/index.md)

[nonJvm]\
actual open class [EOFException](index.md)(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?) : [IOException](../-i-o-exception/index.md)

[jvm]\
actual typealias [EOFException](index.md) = [java.io.EOFException](https://docs.oracle.com/javase/8/docs/api/java/io/EOFException.html)

## Constructors

| | |
|---|---|
| [EOFException](-e-o-f-exception.md) | [common]<br>expect constructor(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)? = null)<br>[nonJvm]<br>actual constructor(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?) |

## Properties

| Name | Summary |
|---|---|
| cause | [common, nonJvm]<br>[common]<br>open val [cause](../-file-not-found-exception/index.md#-654012527%2FProperties%2F1348982416): [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)?<br>[nonJvm]<br>open val [cause](../-file-not-found-exception/index.md#-654012527%2FProperties%2F1730460553): [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)? |
| message | [common, nonJvm]<br>[common]<br>open val [message](../-file-not-found-exception/index.md#1824300659%2FProperties%2F1348982416): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?<br>[nonJvm]<br>open val [message](../-file-not-found-exception/index.md#1824300659%2FProperties%2F1730460553): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)? |
